#include "xml-builtin.h"
static const char xml_feature_btrace_dtd[] = {
  '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
   'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
   '0', '1', '3', '-', '2', '0', '2', '4', ' ', 'F', 
   'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
   'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
   'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
  '\n', 
  ' ', ' ', ' ', ' ', ' ', 'C', 'o', 'p', 'y', 'i', 
   'n', 'g', ' ', 'a', 'n', 'd', ' ', 'd', 'i', 's', 
   't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', ' ', 
   'o', 'f', ' ', 't', 'h', 'i', 's', ' ', 'f', 'i', 
   'l', 'e', ',', ' ', 'w', 'i', 't', 'h', ' ', 'o', 
   'r', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', ' ', 
   'm', 'o', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 
   'o', 'n', ',', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'a', 'r', 'e', ' ', 'p', 
   'e', 'r', 'm', 'i', 't', 't', 'e', 'd', ' ', 'i', 
   'n', ' ', 'a', 'n', 'y', ' ', 'm', 'e', 'd', 'i', 
   'u', 'm', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', 
   ' ', 'r', 'o', 'y', 'a', 'l', 't', 'y', ' ', 'p', 
   'r', 'o', 'v', 'i', 'd', 'e', 'd', ' ', 't', 'h', 
   'e', ' ', 'c', 'o', 'p', 'y', 'r', 'i', 'g', 'h', 
   't', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'n', 'o', 't', 'i', 'c', 
   'e', ' ', 'a', 'n', 'd', ' ', 't', 'h', 'i', 's', 
   ' ', 'n', 'o', 't', 'i', 'c', 'e', ' ', 'a', 'r', 
   'e', ' ', 'p', 'r', 'e', 's', 'e', 'r', 'v', 'e', 
   'd', '.', ' ', ' ', '-', '-', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'b', 't', 'r', 'a', 'c', 'e', ' ', ' ', '(', 'b', 
   'l', 'o', 'c', 'k', '*', ' ', '|', ' ', 'p', 't', 
   ')', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'b', 't', 'r', 'a', 'c', 'e', ' ', ' ', 'v', 'e', 
   'r', 's', 'i', 'o', 'n', ' ', 'C', 'D', 'A', 'T', 
   'A', ' ', ' ', ' ', '#', 'F', 'I', 'X', 'E', 'D', 
   ' ', '"', '1', '.', '0', '"', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'b', 'l', 'o', 'c', 'k', ' ', ' ', ' ', ' ', ' ', 
   ' ', ' ', ' ', 'E', 'M', 'P', 'T', 'Y', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'b', 'l', 'o', 'c', 'k', ' ', ' ', ' ', ' ', ' ', 
   ' ', ' ', ' ', 'b', 'e', 'g', 'i', 'n', ' ', ' ', 
   'C', 'D', 'A', 'T', 'A', ' ', ' ', ' ', '#', 'R', 
   'E', 'Q', 'U', 'I', 'R', 'E', 'D', '\n', 
  ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 
   ' ', ' ', ' ', 'e', 'n', 'd', ' ', ' ', ' ', ' ', 
   'C', 'D', 'A', 'T', 'A', ' ', ' ', ' ', '#', 'R', 
   'E', 'Q', 'U', 'I', 'R', 'E', 'D', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'p', 't', ' ', '(', 'p', 't', '-', 'c', 'o', 'n', 
   'f', 'i', 'g', '?', ',', ' ', 'r', 'a', 'w', '?', 
   ')', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'p', 't', '-', 'c', 'o', 'n', 'f', 'i', 'g', ' ', 
   '(', 'c', 'p', 'u', '?', ')', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'c', 'p', 'u', ' ', 'E', 'M', 'P', 'T', 'Y', '>', 
   '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'c', 'p', 'u', ' ', 'v', 'e', 'n', 'd', 'o', 'r', 
   ' ', ' ', ' ', 'C', 'D', 'A', 'T', 'A', ' ', '#', 
   'R', 'E', 'Q', 'U', 'I', 'R', 'E', 'D', '\n', 
  ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', 'f', 'a', 'm', 'i', 'l', 'y', 
   ' ', ' ', ' ', 'C', 'D', 'A', 'T', 'A', ' ', '#', 
   'R', 'E', 'Q', 'U', 'I', 'R', 'E', 'D', '\n', 
  ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', 'm', 'o', 'd', 'e', 'l', ' ', 
   ' ', ' ', ' ', 'C', 'D', 'A', 'T', 'A', ' ', '#', 
   'R', 'E', 'Q', 'U', 'I', 'R', 'E', 'D', '\n', 
  ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', 's', 't', 'e', 'p', 'p', 'i', 
   'n', 'g', ' ', 'C', 'D', 'A', 'T', 'A', ' ', '#', 
   'R', 'E', 'Q', 'U', 'I', 'R', 'E', 'D', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'r', 'a', 'w', ' ', '(', '#', 'P', 'C', 'D', 'A', 
   'T', 'A', ')', '>', '\n', 
  0 };
static const char xml_feature_btrace_conf_dtd[] = {
  '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
   'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
   '0', '1', '3', '-', '2', '0', '2', '4', ' ', 'F', 
   'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
   'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
   'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
  '\n', 
  ' ', ' ', ' ', ' ', ' ', 'C', 'o', 'p', 'y', 'i', 
   'n', 'g', ' ', 'a', 'n', 'd', ' ', 'd', 'i', 's', 
   't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', ' ', 
   'o', 'f', ' ', 't', 'h', 'i', 's', ' ', 'f', 'i', 
   'l', 'e', ',', ' ', 'w', 'i', 't', 'h', ' ', 'o', 
   'r', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', ' ', 
   'm', 'o', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 
   'o', 'n', ',', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'a', 'r', 'e', ' ', 'p', 
   'e', 'r', 'm', 'i', 't', 't', 'e', 'd', ' ', 'i', 
   'n', ' ', 'a', 'n', 'y', ' ', 'm', 'e', 'd', 'i', 
   'u', 'm', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', 
   ' ', 'r', 'o', 'y', 'a', 'l', 't', 'y', ' ', 'p', 
   'r', 'o', 'v', 'i', 'd', 'e', 'd', ' ', 't', 'h', 
   'e', ' ', 'c', 'o', 'p', 'y', 'r', 'i', 'g', 'h', 
   't', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'n', 'o', 't', 'i', 'c', 
   'e', ' ', 'a', 'n', 'd', ' ', 't', 'h', 'i', 's', 
   ' ', 'n', 'o', 't', 'i', 'c', 'e', ' ', 'a', 'r', 
   'e', ' ', 'p', 'r', 'e', 's', 'e', 'r', 'v', 'e', 
   'd', '.', ' ', ' ', '-', '-', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'b', 't', 'r', 'a', 'c', 'e', '-', 'c', 'o', 'n', 
   'f', '\011', '(', 'b', 't', 's', '?', ',', ' ', 'p', 
   't', '?', ')', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'b', 't', 'r', 'a', 'c', 'e', '-', 'c', 'o', 'n', 
   'f', '\011', 'v', 'e', 'r', 's', 'i', 'o', 'n', '\011', 
   'C', 'D', 'A', 'T', 'A', '\011', '#', 'F', 'I', 'X', 
   'E', 'D', ' ', '"', '1', '.', '0', '"', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'b', 't', 's', '\011', 'E', 'M', 'P', 'T', 'Y', '>', 
   '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'b', 't', 's', '\011', 's', 'i', 'z', 'e', '\011', 'C', 
   'D', 'A', 'T', 'A', '\011', '#', 'I', 'M', 'P', 'L', 
   'I', 'E', 'D', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'p', 't', '\011', 'E', 'M', 'P', 'T', 'Y', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'p', 't', '\011', 's', 'i', 'z', 'e', '\011', 'C', 'D', 
   'A', 'T', 'A', '\011', '#', 'I', 'M', 'P', 'L', 'I', 
   'E', 'D', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'p', 't', '\011', 'p', 't', 'w', 'r', 'i', 't', 'e', 
   '\011', '(', 'y', 'e', 's', ' ', '|', ' ', 'n', 'o', 
   ')', ' ', '#', 'I', 'M', 'P', 'L', 'I', 'E', 'D', 
   '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'p', 't', '\011', 'e', 'v', 'e', 'n', 't', '-', 't', 
   'r', 'a', 'c', 'i', 'n', 'g', '\011', '(', 'y', 'e', 
   's', ' ', '|', ' ', 'n', 'o', ')', '\011', '#', 'I', 
   'M', 'P', 'L', 'I', 'E', 'D', '>', '\n', 
  0 };
static const char xml_feature_gdb_target_dtd[] = {
  '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
   'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
   '0', '0', '7', '-', '2', '0', '2', '4', ' ', 'F', 
   'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
   'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
   'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
  '\n', 
  ' ', ' ', ' ', ' ', ' ', 'C', 'o', 'p', 'y', 'i', 
   'n', 'g', ' ', 'a', 'n', 'd', ' ', 'd', 'i', 's', 
   't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', ' ', 
   'o', 'f', ' ', 't', 'h', 'i', 's', ' ', 'f', 'i', 
   'l', 'e', ',', ' ', 'w', 'i', 't', 'h', ' ', 'o', 
   'r', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', ' ', 
   'm', 'o', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 
   'o', 'n', ',', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'a', 'r', 'e', ' ', 'p', 
   'e', 'r', 'm', 'i', 't', 't', 'e', 'd', ' ', 'i', 
   'n', ' ', 'a', 'n', 'y', ' ', 'm', 'e', 'd', 'i', 
   'u', 'm', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', 
   ' ', 'r', 'o', 'y', 'a', 'l', 't', 'y', ' ', 'p', 
   'r', 'o', 'v', 'i', 'd', 'e', 'd', ' ', 't', 'h', 
   'e', ' ', 'c', 'o', 'p', 'y', 'r', 'i', 'g', 'h', 
   't', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'n', 'o', 't', 'i', 'c', 
   'e', ' ', 'a', 'n', 'd', ' ', 't', 'h', 'i', 's', 
   ' ', 'n', 'o', 't', 'i', 'c', 'e', ' ', 'a', 'r', 
   'e', ' ', 'p', 'r', 'e', 's', 'e', 'r', 'v', 'e', 
   'd', '.', ' ', ' ', '-', '-', '>', '\n', 
  '\n', 
  '<', '!', '-', '-', ' ', 'T', 'h', 'e', ' ', 'r', 
   'o', 'o', 't', ' ', 'e', 'l', 'e', 'm', 'e', 'n', 
   't', ' ', 'o', 'f', ' ', 'a', ' ', 'G', 'D', 'B', 
   ' ', 't', 'a', 'r', 'g', 'e', 't', ' ', 'd', 'e', 
   's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', ' ', 
   'i', 's', ' ', '<', 't', 'a', 'r', 'g', 'e', 't', 
   '>', '.', ' ', ' ', '-', '-', '>', '\n', 
  '\n', 
  '<', '!', '-', '-', ' ', 'T', 'h', 'e', ' ', 'o', 
   's', 'a', 'b', 'i', ' ', 'a', 'n', 'd', ' ', 'c', 
   'o', 'm', 'p', 'a', 't', 'i', 'b', 'l', 'e', ' ', 
   'e', 'l', 'e', 'm', 'e', 'n', 't', 's', ' ', 'w', 
   'e', 'r', 'e', ' ', 'a', 'd', 'd', 'e', 'd', ' ', 
   'p', 'o', 's', 't', ' ', 'G', 'D', 'B', ' ', '6', 
   '.', '8', '.', ' ', ' ', 'T', 'h', 'e', ' ', 'v', 
   'e', 'r', 's', 'i', 'o', 'n', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'w', 'a', 's', 'n', '\'', 
   't', ' ', 'b', 'u', 'm', 'p', 'e', 'd', ',', ' ', 
   's', 'i', 'n', 'c', 'e', ' ', 'o', 'l', 'd', 'e', 
   'r', ' ', 'G', 'D', 'B', 's', ' ', 's', 'i', 'l', 
   'e', 'n', 't', 'l', 'y', ' ', 'i', 'g', 'n', 'o', 
   'r', 'e', ' ', 'u', 'n', 'k', 'n', 'o', 'w', 'n', 
   ' ', 'e', 'l', 'e', 'm', 'e', 'n', 't', 's', '.', 
   ' ', ' ', '-', '-', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   't', 'a', 'r', 'g', 'e', 't', '\011', '(', 'a', 'r', 
   'c', 'h', 'i', 't', 'e', 'c', 't', 'u', 'r', 'e', 
   '?', ',', ' ', 'o', 's', 'a', 'b', 'i', '?', ',', 
   ' ', 'c', 'o', 'm', 'p', 'a', 't', 'i', 'b', 'l', 
   'e', '*', ',', ' ', 'f', 'e', 'a', 't', 'u', 'r', 
   'e', '*', ')', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   't', 'a', 'r', 'g', 'e', 't', '\n', 
  '\011', 'v', 'e', 'r', 's', 'i', 'o', 'n', '\011', '\011', 
   'C', 'D', 'A', 'T', 'A', '\011', '#', 'F', 'I', 'X', 
   'E', 'D', ' ', '"', '1', '.', '0', '"', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'a', 'r', 'c', 'h', 'i', 't', 'e', 'c', 't', 'u', 
   'r', 'e', '\011', '(', '#', 'P', 'C', 'D', 'A', 'T', 
   'A', ')', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'o', 's', 'a', 'b', 'i', '\011', '(', '#', 'P', 'C', 
   'D', 'A', 'T', 'A', ')', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'c', 'o', 'm', 'p', 'a', 't', 'i', 'b', 'l', 'e', 
   '\011', '(', '#', 'P', 'C', 'D', 'A', 'T', 'A', ')', 
   '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'f', 'e', 'a', 't', 'u', 'r', 'e', '\n', 
  '\011', '(', '(', 'v', 'e', 'c', 't', 'o', 'r', ' ', 
   '|', ' ', 'f', 'l', 'a', 'g', 's', ' ', '|', ' ', 
   's', 't', 'r', 'u', 'c', 't', ' ', '|', ' ', 'u', 
   'n', 'i', 'o', 'n', ' ', ')', '*', ',', ' ', 'r', 
   'e', 'g', '*', ')', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'f', 'e', 'a', 't', 'u', 'r', 'e', '\n', 
  '\011', 'n', 'a', 'm', 'e', '\011', '\011', 'I', 'D', '\011', 
   '#', 'R', 'E', 'Q', 'U', 'I', 'R', 'E', 'D', '>', 
   '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'r', 'e', 'g', '\011', '\011', '(', 'd', 'e', 's', 'c', 
   'r', 'i', 'p', 't', 'i', 'o', 'n', '*', ')', '>', 
   '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'r', 'e', 'g', '\n', 
  '\011', 'n', 'a', 'm', 'e', '\011', '\011', 'C', 'D', 'A', 
   'T', 'A', '\011', '#', 'R', 'E', 'Q', 'U', 'I', 'R', 
   'E', 'D', '\n', 
  '\011', 'b', 'i', 't', 's', 'i', 'z', 'e', '\011', '\011', 
   'C', 'D', 'A', 'T', 'A', '\011', '#', 'R', 'E', 'Q', 
   'U', 'I', 'R', 'E', 'D', '\n', 
  '\011', 'r', 'e', 'g', 'n', 'u', 'm', '\011', '\011', 'C', 
   'D', 'A', 'T', 'A', '\011', '#', 'I', 'M', 'P', 'L', 
   'I', 'E', 'D', '\n', 
  '\011', 's', 'a', 'v', 'e', '-', 'r', 'e', 's', 't', 
   'o', 'r', 'e', '\011', '(', 'y', 'e', 's', ' ', '|', 
   ' ', 'n', 'o', ')', ' ', '\'', 'y', 'e', 's', '\'', 
   '\n', 
  '\011', 't', 'y', 'p', 'e', '\011', '\011', 'C', 'D', 'A', 
   'T', 'A', '\011', '\'', 'i', 'n', 't', '\'', '\n', 
  '\011', 'g', 'r', 'o', 'u', 'p', '\011', '\011', 'C', 'D', 
   'A', 'T', 'A', '\011', '#', 'I', 'M', 'P', 'L', 'I', 
   'E', 'D', '\n', 
  '\011', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'v', 'e', 'c', 't', 'o', 'r', '\011', 'E', 'M', 'P', 
   'T', 'Y', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'v', 'e', 'c', 't', 'o', 'r', '\n', 
  '\011', 'i', 'd', '\011', '\011', 'C', 'D', 'A', 'T', 'A', 
   '\011', '#', 'R', 'E', 'Q', 'U', 'I', 'R', 'E', 'D', 
   '\n', 
  '\011', 't', 'y', 'p', 'e', '\011', '\011', 'C', 'D', 'A', 
   'T', 'A', '\011', '#', 'R', 'E', 'Q', 'U', 'I', 'R', 
   'E', 'D', '\n', 
  '\011', 'c', 'o', 'u', 'n', 't', '\011', '\011', 'C', 'D', 
   'A', 'T', 'A', '\011', '#', 'R', 'E', 'Q', 'U', 'I', 
   'R', 'E', 'D', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'f', 'l', 'a', 'g', 's', '\011', '\011', '(', 'f', 'i', 
   'e', 'l', 'd', '+', ')', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'f', 'l', 'a', 'g', 's', '\n', 
  '\011', 'i', 'd', '\011', '\011', 'C', 'D', 'A', 'T', 'A', 
   '\011', '#', 'R', 'E', 'Q', 'U', 'I', 'R', 'E', 'D', 
   '\n', 
  '\011', 's', 'i', 'z', 'e', '\011', '\011', 'C', 'D', 'A', 
   'T', 'A', '\011', '#', 'R', 'E', 'Q', 'U', 'I', 'R', 
   'E', 'D', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'e', 'n', 'u', 'm', '\011', '\011', '(', 'e', 'v', 'a', 
   'l', 'u', 'e', '+', ')', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'e', 'n', 'u', 'm', '\n', 
  '\011', 'i', 'd', '\011', '\011', 'C', 'D', 'A', 'T', 'A', 
   '\011', '#', 'R', 'E', 'Q', 'U', 'I', 'R', 'E', 'D', 
   '\n', 
  '\011', 's', 'i', 'z', 'e', '\011', '\011', 'C', 'D', 'A', 
   'T', 'A', '\011', '#', 'R', 'E', 'Q', 'U', 'I', 'R', 
   'E', 'D', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   's', 't', 'r', 'u', 'c', 't', '\011', '(', 'f', 'i', 
   'e', 'l', 'd', '+', ')', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   's', 't', 'r', 'u', 'c', 't', '\n', 
  '\011', 'i', 'd', '\011', '\011', 'C', 'D', 'A', 'T', 'A', 
   '\011', '#', 'R', 'E', 'Q', 'U', 'I', 'R', 'E', 'D', 
   '\n', 
  '\011', 's', 'i', 'z', 'e', '\011', '\011', 'C', 'D', 'A', 
   'T', 'A', '\011', '#', 'I', 'M', 'P', 'L', 'I', 'E', 
   'D', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'u', 'n', 'i', 'o', 'n', '\011', '\011', '(', 'f', 'i', 
   'e', 'l', 'd', '+', ')', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'u', 'n', 'i', 'o', 'n', '\n', 
  '\011', 'i', 'd', '\011', '\011', 'C', 'D', 'A', 'T', 'A', 
   '\011', '#', 'R', 'E', 'Q', 'U', 'I', 'R', 'E', 'D', 
   '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'f', 'i', 'e', 'l', 'd', '\011', '\011', 'E', 'M', 'P', 
   'T', 'Y', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'f', 'i', 'e', 'l', 'd', '\n', 
  '\011', 'n', 'a', 'm', 'e', '\011', '\011', 'C', 'D', 'A', 
   'T', 'A', '\011', '#', 'R', 'E', 'Q', 'U', 'I', 'R', 
   'E', 'D', '\n', 
  '\011', 't', 'y', 'p', 'e', '\011', '\011', 'C', 'D', 'A', 
   'T', 'A', '\011', '#', 'I', 'M', 'P', 'L', 'I', 'E', 
   'D', '\n', 
  '\011', 's', 't', 'a', 'r', 't', '\011', '\011', 'C', 'D', 
   'A', 'T', 'A', '\011', '#', 'I', 'M', 'P', 'L', 'I', 
   'E', 'D', '\n', 
  '\011', 'e', 'n', 'd', '\011', '\011', 'C', 'D', 'A', 'T', 
   'A', '\011', '#', 'I', 'M', 'P', 'L', 'I', 'E', 'D', 
   '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'e', 'v', 'a', 'l', 'u', 'e', '\011', 'E', 'M', 'P', 
   'T', 'Y', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'e', 'v', 'a', 'l', 'u', 'e', '\n', 
  '\011', 'n', 'a', 'm', 'e', '\011', '\011', 'C', 'D', 'A', 
   'T', 'A', '\011', '#', 'R', 'E', 'Q', 'U', 'I', 'R', 
   'E', 'D', '\n', 
  '\011', 'v', 'a', 'l', 'u', 'e', '\011', '\011', 'C', 'D', 
   'A', 'T', 'A', '\011', '#', 'R', 'E', 'Q', 'U', 'I', 
   'R', 'E', 'D', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'N', 'T', 'I', 'T', 'Y', ' ', '%', 
   ' ', 'x', 'i', 'n', 'c', 'l', 'u', 'd', 'e', ' ', 
   'S', 'Y', 'S', 'T', 'E', 'M', ' ', '"', 'x', 'i', 
   'n', 'c', 'l', 'u', 'd', 'e', '.', 'd', 't', 'd', 
   '"', '>', '\n', 
  '%', 'x', 'i', 'n', 'c', 'l', 'u', 'd', 'e', ';', 
   '\n', 
  0 };
static const char xml_feature_library_list_dtd[] = {
  '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
   'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
   '0', '0', '7', '-', '2', '0', '2', '4', ' ', 'F', 
   'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
   'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
   'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
  '\n', 
  ' ', ' ', ' ', ' ', ' ', 'C', 'o', 'p', 'y', 'i', 
   'n', 'g', ' ', 'a', 'n', 'd', ' ', 'd', 'i', 's', 
   't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', ' ', 
   'o', 'f', ' ', 't', 'h', 'i', 's', ' ', 'f', 'i', 
   'l', 'e', ',', ' ', 'w', 'i', 't', 'h', ' ', 'o', 
   'r', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', ' ', 
   'm', 'o', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 
   'o', 'n', ',', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'a', 'r', 'e', ' ', 'p', 
   'e', 'r', 'm', 'i', 't', 't', 'e', 'd', ' ', 'i', 
   'n', ' ', 'a', 'n', 'y', ' ', 'm', 'e', 'd', 'i', 
   'u', 'm', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', 
   ' ', 'r', 'o', 'y', 'a', 'l', 't', 'y', ' ', 'p', 
   'r', 'o', 'v', 'i', 'd', 'e', 'd', ' ', 't', 'h', 
   'e', ' ', 'c', 'o', 'p', 'y', 'r', 'i', 'g', 'h', 
   't', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'n', 'o', 't', 'i', 'c', 
   'e', ' ', 'a', 'n', 'd', ' ', 't', 'h', 'i', 's', 
   ' ', 'n', 'o', 't', 'i', 'c', 'e', ' ', 'a', 'r', 
   'e', ' ', 'p', 'r', 'e', 's', 'e', 'r', 'v', 'e', 
   'd', '.', ' ', ' ', '-', '-', '>', '\n', 
  '\n', 
  '<', '!', '-', '-', ' ', 'l', 'i', 'b', 'r', 'a', 
   'r', 'y', '-', 'l', 'i', 's', 't', ':', ' ', 'R', 
   'o', 'o', 't', ' ', 'e', 'l', 'e', 'm', 'e', 'n', 
   't', ' ', 'w', 'i', 't', 'h', ' ', 'v', 'e', 'r', 
   's', 'i', 'o', 'n', 'i', 'n', 'g', ' ', '-', '-', 
   '>', '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', '-', 'l', 'i', 
   's', 't', ' ', ' ', '(', 'l', 'i', 'b', 'r', 'a', 
   'r', 'y', ')', '*', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', '-', 'l', 'i', 
   's', 't', ' ', ' ', 'v', 'e', 'r', 's', 'i', 'o', 
   'n', ' ', 'C', 'D', 'A', 'T', 'A', ' ', ' ', ' ', 
   '#', 'F', 'I', 'X', 'E', 'D', ' ', ' ', '"', '1', 
   '.', '0', '"', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', '(', 's', 'e', 'g', 'm', 'e', 
   'n', 't', '*', ',', ' ', 's', 'e', 'c', 't', 'i', 
   'o', 'n', '*', ')', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', 'n', 'a', 'm', 'e', ' ', ' ', 
   ' ', ' ', 'C', 'D', 'A', 'T', 'A', ' ', ' ', ' ', 
   '#', 'R', 'E', 'Q', 'U', 'I', 'R', 'E', 'D', '>', 
   '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   's', 'e', 'g', 'm', 'e', 'n', 't', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', 'E', 'M', 'P', 'T', 'Y', '>', 
   '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   's', 'e', 'g', 'm', 'e', 'n', 't', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', 'a', 'd', 'd', 'r', 'e', 's', 
   's', ' ', 'C', 'D', 'A', 'T', 'A', ' ', ' ', ' ', 
   '#', 'R', 'E', 'Q', 'U', 'I', 'R', 'E', 'D', '>', 
   '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   's', 'e', 'c', 't', 'i', 'o', 'n', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', 'E', 'M', 'P', 'T', 'Y', '>', 
   '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   's', 'e', 'c', 't', 'i', 'o', 'n', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', 'a', 'd', 'd', 'r', 'e', 's', 
   's', ' ', 'C', 'D', 'A', 'T', 'A', ' ', ' ', ' ', 
   '#', 'R', 'E', 'Q', 'U', 'I', 'R', 'E', 'D', '>', 
   '\n', 
  0 };
static const char xml_feature_library_list_aix_dtd[] = {
  '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
   'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
   '0', '1', '3', '-', '2', '0', '2', '4', ' ', 'F', 
   'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
   'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
   'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
  '\n', 
  ' ', ' ', ' ', ' ', ' ', 'C', 'o', 'p', 'y', 'i', 
   'n', 'g', ' ', 'a', 'n', 'd', ' ', 'd', 'i', 's', 
   't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', ' ', 
   'o', 'f', ' ', 't', 'h', 'i', 's', ' ', 'f', 'i', 
   'l', 'e', ',', ' ', 'w', 'i', 't', 'h', ' ', 'o', 
   'r', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', ' ', 
   'm', 'o', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 
   'o', 'n', ',', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'a', 'r', 'e', ' ', 'p', 
   'e', 'r', 'm', 'i', 't', 't', 'e', 'd', ' ', 'i', 
   'n', ' ', 'a', 'n', 'y', ' ', 'm', 'e', 'd', 'i', 
   'u', 'm', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', 
   ' ', 'r', 'o', 'y', 'a', 'l', 't', 'y', ' ', 'p', 
   'r', 'o', 'v', 'i', 'd', 'e', 'd', ' ', 't', 'h', 
   'e', ' ', 'c', 'o', 'p', 'y', 'r', 'i', 'g', 'h', 
   't', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'n', 'o', 't', 'i', 'c', 
   'e', ' ', 'a', 'n', 'd', ' ', 't', 'h', 'i', 's', 
   ' ', 'n', 'o', 't', 'i', 'c', 'e', ' ', 'a', 'r', 
   'e', ' ', 'p', 'r', 'e', 's', 'e', 'r', 'v', 'e', 
   'd', '.', ' ', ' ', '-', '-', '>', '\n', 
  '\n', 
  '<', '!', '-', '-', ' ', 'l', 'i', 'b', 'r', 'a', 
   'r', 'y', '-', 'l', 'i', 's', 't', ':', ' ', 'R', 
   'o', 'o', 't', ' ', 'e', 'l', 'e', 'm', 'e', 'n', 
   't', ' ', 'w', 'i', 't', 'h', ' ', 'v', 'e', 'r', 
   's', 'i', 'o', 'n', 'i', 'n', 'g', ' ', '-', '-', 
   '>', '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', '-', 'l', 'i', 
   's', 't', '-', 'a', 'i', 'x', ' ', ' ', '(', 'l', 
   'i', 'b', 'r', 'a', 'r', 'y', ')', '*', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', '-', 'l', 'i', 
   's', 't', '-', 'a', 'i', 'x', ' ', ' ', 'v', 'e', 
   'r', 's', 'i', 'o', 'n', ' ', 'C', 'D', 'A', 'T', 
   'A', ' ', ' ', ' ', '#', 'F', 'I', 'X', 'E', 'D', 
   ' ', ' ', '"', '1', '.', '0', '"', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', ' ', ' ', '(', 
   'n', 'a', 'm', 'e', ',', ' ', 'm', 'e', 'm', 'b', 
   'e', 'r', ',', ' ', 't', 'e', 'x', 't', '_', 'a', 
   'd', 'd', 'r', ',', ' ', 't', 'e', 'x', 't', '_', 
   's', 'i', 'z', 'e', ',', ' ', 'd', 'a', 't', 'a', 
   '_', 'a', 'd', 'd', 'r', ',', ' ', 'd', 'a', 't', 
   'a', '_', 's', 'i', 'z', 'e', ')', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', ' ', ' ', 'n', 
   'a', 'm', 'e', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 
   'C', 'D', 'A', 'T', 'A', ' ', ' ', ' ', '#', 'R', 
   'E', 'Q', 'U', 'I', 'R', 'E', 'D', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', ' ', ' ', 'm', 
   'e', 'm', 'b', 'e', 'r', ' ', ' ', ' ', ' ', ' ', 
   'C', 'D', 'A', 'T', 'A', ' ', ' ', ' ', '#', 'R', 
   'E', 'Q', 'U', 'I', 'R', 'E', 'D', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', ' ', ' ', 't', 
   'e', 'x', 't', '_', 'a', 'd', 'd', 'r', ' ', ' ', 
   'C', 'D', 'A', 'T', 'A', ' ', ' ', ' ', '#', 'R', 
   'E', 'Q', 'U', 'I', 'R', 'E', 'D', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', ' ', ' ', 't', 
   'e', 'x', 't', '_', 's', 'i', 'z', 'e', ' ', ' ', 
   'C', 'D', 'A', 'T', 'A', ' ', ' ', ' ', '#', 'R', 
   'E', 'Q', 'U', 'I', 'R', 'E', 'D', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', ' ', ' ', 'd', 
   'a', 't', 'a', '_', 'a', 'd', 'd', 'r', ' ', ' ', 
   'C', 'D', 'A', 'T', 'A', ' ', ' ', ' ', '#', 'R', 
   'E', 'Q', 'U', 'I', 'R', 'E', 'D', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', ' ', ' ', 'd', 
   'a', 't', 'a', '_', 's', 'i', 'z', 'e', ' ', ' ', 
   'C', 'D', 'A', 'T', 'A', ' ', ' ', ' ', '#', 'R', 
   'E', 'Q', 'U', 'I', 'R', 'E', 'D', '>', '\n', 
  '\n', 
  0 };
static const char xml_feature_library_list_svr4_dtd[] = {
  '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
   'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
   '0', '1', '1', '-', '2', '0', '2', '4', ' ', 'F', 
   'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
   'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
   'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
  '\n', 
  ' ', ' ', ' ', ' ', ' ', 'C', 'o', 'p', 'y', 'i', 
   'n', 'g', ' ', 'a', 'n', 'd', ' ', 'd', 'i', 's', 
   't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', ' ', 
   'o', 'f', ' ', 't', 'h', 'i', 's', ' ', 'f', 'i', 
   'l', 'e', ',', ' ', 'w', 'i', 't', 'h', ' ', 'o', 
   'r', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', ' ', 
   'm', 'o', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 
   'o', 'n', ',', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'a', 'r', 'e', ' ', 'p', 
   'e', 'r', 'm', 'i', 't', 't', 'e', 'd', ' ', 'i', 
   'n', ' ', 'a', 'n', 'y', ' ', 'm', 'e', 'd', 'i', 
   'u', 'm', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', 
   ' ', 'r', 'o', 'y', 'a', 'l', 't', 'y', ' ', 'p', 
   'r', 'o', 'v', 'i', 'd', 'e', 'd', ' ', 't', 'h', 
   'e', ' ', 'c', 'o', 'p', 'y', 'r', 'i', 'g', 'h', 
   't', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'n', 'o', 't', 'i', 'c', 
   'e', ' ', 'a', 'n', 'd', ' ', 't', 'h', 'i', 's', 
   ' ', 'n', 'o', 't', 'i', 'c', 'e', ' ', 'a', 'r', 
   'e', ' ', 'p', 'r', 'e', 's', 'e', 'r', 'v', 'e', 
   'd', '.', ' ', ' ', '-', '-', '>', '\n', 
  '\n', 
  '<', '!', '-', '-', ' ', 'l', 'i', 'b', 'r', 'a', 
   'r', 'y', '-', 'l', 'i', 's', 't', '-', 's', 'v', 
   'r', '4', ':', ' ', 'R', 'o', 'o', 't', ' ', 'e', 
   'l', 'e', 'm', 'e', 'n', 't', ' ', 'w', 'i', 't', 
   'h', ' ', 'v', 'e', 'r', 's', 'i', 'o', 'n', 'i', 
   'n', 'g', ' ', '-', '-', '>', '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', '-', 'l', 'i', 
   's', 't', '-', 's', 'v', 'r', '4', ' ', ' ', '(', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', ')', '*', '>', 
   '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', '-', 'l', 'i', 
   's', 't', '-', 's', 'v', 'r', '4', ' ', ' ', 'v', 
   'e', 'r', 's', 'i', 'o', 'n', ' ', 'C', 'D', 'A', 
   'T', 'A', ' ', ' ', ' ', '#', 'F', 'I', 'X', 'E', 
   'D', ' ', ' ', '"', '1', '.', '0', '"', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', '-', 'l', 'i', 
   's', 't', '-', 's', 'v', 'r', '4', ' ', ' ', 'm', 
   'a', 'i', 'n', '-', 'l', 'm', ' ', 'C', 'D', 'A', 
   'T', 'A', ' ', ' ', ' ', '#', 'I', 'M', 'P', 'L', 
   'I', 'E', 'D', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 'E', 
   'M', 'P', 'T', 'Y', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 'n', 
   'a', 'm', 'e', ' ', ' ', ' ', ' ', 'C', 'D', 'A', 
   'T', 'A', ' ', ' ', ' ', '#', 'R', 'E', 'Q', 'U', 
   'I', 'R', 'E', 'D', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 'l', 
   'm', ' ', ' ', ' ', ' ', ' ', ' ', 'C', 'D', 'A', 
   'T', 'A', ' ', ' ', ' ', '#', 'R', 'E', 'Q', 'U', 
   'I', 'R', 'E', 'D', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 'l', 
   '_', 'a', 'd', 'd', 'r', ' ', ' ', 'C', 'D', 'A', 
   'T', 'A', ' ', ' ', ' ', '#', 'R', 'E', 'Q', 'U', 
   'I', 'R', 'E', 'D', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 'l', 
   '_', 'l', 'd', ' ', ' ', ' ', ' ', 'C', 'D', 'A', 
   'T', 'A', ' ', ' ', ' ', '#', 'R', 'E', 'Q', 'U', 
   'I', 'R', 'E', 'D', '>', '\n', 
  '<', '!', '-', '-', ' ', 'a', 'd', 'd', 'e', 'd', 
   ' ', 'l', 'm', 'i', 'd', ' ', 'a', 't', 't', 'r', 
   'i', 'b', 'u', 't', 'e', ' ', 't', 'o', ' ', 'w', 
   'h', 'a', 't', ' ', 's', 'h', 'o', 'u', 'l', 'd', 
   ' ', 'h', 'a', 'v', 'e', ' ', 'b', 'e', 'c', 'o', 
   'm', 'e', ' ', 'v', 'e', 'r', 's', 'i', 'o', 'n', 
   ' ', '1', '.', '1', ' ', 'b', 'u', 't', '\n', 
  ' ', ' ', ' ', ' ', ' ', 's', 'i', 'n', 'c', 'e', 
   ' ', 't', 'h', 'i', 's', ' ', 'g', 'e', 'n', 'e', 
   'r', 'a', 't', 'e', 's', ' ', 'a', ' ', 'w', 'a', 
   'r', 'n', 'i', 'n', 'g', ' ', 'i', 'n', ' ', 'G', 
   'D', 'B', ' ', 'a', 'n', 'd', ' ', 's', 'i', 'n', 
   'c', 'e', ' ', 'u', 'n', 'k', 'n', 'o', 'w', 'n', 
   ' ', 'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 
   's', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'a', 'r', 'e', ' ', 'i', 
   'g', 'n', 'o', 'r', 'e', 'd', ',', ' ', 'a', 'n', 
   'y', 'w', 'a', 'y', ',', ' ', 'l', 'e', 'a', 'v', 
   'i', 'n', 'g', ' ', 't', 'h', 'e', ' ', 'v', 'e', 
   'r', 's', 'i', 'o', 'n', ' ', 'a', 't', ' ', '1', 
   '.', '0', '.', ' ', '-', '-', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'l', 'i', 'b', 'r', 'a', 'r', 'y', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 'l', 
   'm', 'i', 'd', ' ', ' ', ' ', ' ', 'C', 'D', 'A', 
   'T', 'A', ' ', ' ', ' ', '#', 'I', 'M', 'P', 'L', 
   'I', 'E', 'D', '>', '\n', 
  0 };
static const char xml_feature_osdata_dtd[] = {
  '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
   'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
   '0', '0', '8', '-', '2', '0', '2', '4', ' ', 'F', 
   'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
   'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
   'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
  '\n', 
  ' ', ' ', ' ', ' ', ' ', 'C', 'o', 'p', 'y', 'i', 
   'n', 'g', ' ', 'a', 'n', 'd', ' ', 'd', 'i', 's', 
   't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', ' ', 
   'o', 'f', ' ', 't', 'h', 'i', 's', ' ', 'f', 'i', 
   'l', 'e', ',', ' ', 'w', 'i', 't', 'h', ' ', 'o', 
   'r', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', ' ', 
   'm', 'o', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 
   'o', 'n', ',', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'a', 'r', 'e', ' ', 'p', 
   'e', 'r', 'm', 'i', 't', 't', 'e', 'd', ' ', 'i', 
   'n', ' ', 'a', 'n', 'y', ' ', 'm', 'e', 'd', 'i', 
   'u', 'm', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', 
   ' ', 'r', 'o', 'y', 'a', 'l', 't', 'y', ' ', 'p', 
   'r', 'o', 'v', 'i', 'd', 'e', 'd', ' ', 't', 'h', 
   'e', ' ', 'c', 'o', 'p', 'y', 'r', 'i', 'g', 'h', 
   't', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'n', 'o', 't', 'i', 'c', 
   'e', ' ', 'a', 'n', 'd', ' ', 't', 'h', 'i', 's', 
   ' ', 'n', 'o', 't', 'i', 'c', 'e', ' ', 'a', 'r', 
   'e', ' ', 'p', 'r', 'e', 's', 'e', 'r', 'v', 'e', 
   'd', '.', ' ', ' ', '-', '-', '>', '\n', 
  '\n', 
  '<', '!', '-', '-', ' ', 'o', 's', 'd', 'a', 't', 
   'a', ':', ' ', 'R', 'o', 'o', 't', ' ', 'e', 'l', 
   'e', 'm', 'e', 'n', 't', ' ', 'w', 'i', 't', 'h', 
   ' ', 'v', 'e', 'r', 's', 'i', 'o', 'n', 'i', 'n', 
   'g', ' ', '-', '-', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'o', 's', 'd', 'a', 't', 'a', ' ', '(', 'i', 't', 
   'e', 'm', '*', ')', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'o', 's', 'd', 'a', 't', 'a', ' ', 'v', 'e', 'r', 
   's', 'i', 'o', 'n', ' ', 'C', 'D', 'A', 'T', 'A', 
   ' ', '#', 'F', 'I', 'X', 'E', 'D', ' ', '"', '1', 
   '.', '0', '"', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'o', 's', 'd', 'a', 't', 'a', ' ', 't', 'y', 'p', 
   'e', ' ', 'C', 'D', 'A', 'T', 'A', ' ', '#', 'R', 
   'E', 'Q', 'U', 'I', 'R', 'E', 'D', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'i', 't', 'e', 'm', ' ', '(', 'c', 'o', 'l', 'u', 
   'm', 'n', '*', ')', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'c', 'o', 'l', 'u', 'm', 'n', ' ', '(', '#', 'P', 
   'C', 'D', 'A', 'T', 'A', ')', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'c', 'o', 'l', 'u', 'm', 'n', ' ', 'n', 'a', 'm', 
   'e', ' ', 'C', 'D', 'A', 'T', 'A', ' ', '#', 'R', 
   'E', 'Q', 'U', 'I', 'R', 'E', 'D', '>', '\n', 
  0 };
static const char xml_feature_threads_dtd[] = {
  '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
   'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
   '0', '0', '8', '-', '2', '0', '2', '4', ' ', 'F', 
   'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
   'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
   'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
  '\n', 
  ' ', ' ', ' ', ' ', ' ', 'C', 'o', 'p', 'y', 'i', 
   'n', 'g', ' ', 'a', 'n', 'd', ' ', 'd', 'i', 's', 
   't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', ' ', 
   'o', 'f', ' ', 't', 'h', 'i', 's', ' ', 'f', 'i', 
   'l', 'e', ',', ' ', 'w', 'i', 't', 'h', ' ', 'o', 
   'r', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', ' ', 
   'm', 'o', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 
   'o', 'n', ',', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'a', 'r', 'e', ' ', 'p', 
   'e', 'r', 'm', 'i', 't', 't', 'e', 'd', ' ', 'i', 
   'n', ' ', 'a', 'n', 'y', ' ', 'm', 'e', 'd', 'i', 
   'u', 'm', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', 
   ' ', 'r', 'o', 'y', 'a', 'l', 't', 'y', ' ', 'p', 
   'r', 'o', 'v', 'i', 'd', 'e', 'd', ' ', 't', 'h', 
   'e', ' ', 'c', 'o', 'p', 'y', 'r', 'i', 'g', 'h', 
   't', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'n', 'o', 't', 'i', 'c', 
   'e', ' ', 'a', 'n', 'd', ' ', 't', 'h', 'i', 's', 
   ' ', 'n', 'o', 't', 'i', 'c', 'e', ' ', 'a', 'r', 
   'e', ' ', 'p', 'r', 'e', 's', 'e', 'r', 'v', 'e', 
   'd', '.', ' ', ' ', '-', '-', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   't', 'h', 'r', 'e', 'a', 'd', 's', ' ', '(', 't', 
   'h', 'r', 'e', 'a', 'd', '*', ')', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   't', 'h', 'r', 'e', 'a', 'd', 's', ' ', 'v', 'e', 
   'r', 's', 'i', 'o', 'n', ' ', 'C', 'D', 'A', 'T', 
   'A', ' ', '#', 'F', 'I', 'X', 'E', 'D', ' ', '"', 
   '1', '.', '0', '"', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   't', 'h', 'r', 'e', 'a', 'd', ' ', '(', '#', 'P', 
   'C', 'D', 'A', 'T', 'A', ')', '>', '\n', 
  '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   't', 'h', 'r', 'e', 'a', 'd', ' ', 'i', 'd', ' ', 
   'C', 'D', 'A', 'T', 'A', ' ', '#', 'R', 'E', 'Q', 
   'U', 'I', 'R', 'E', 'D', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   't', 'h', 'r', 'e', 'a', 'd', ' ', 'c', 'o', 'r', 
   'e', ' ', 'C', 'D', 'A', 'T', 'A', ' ', '#', 'I', 
   'M', 'P', 'L', 'I', 'E', 'D', '>', '\n', 
  0 };
static const char xml_feature_traceframe_info_dtd[] = {
  '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
   'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
   '0', '1', '0', '-', '2', '0', '2', '4', ' ', 'F', 
   'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
   'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
   'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
  '\n', 
  ' ', ' ', ' ', ' ', ' ', 'C', 'o', 'p', 'y', 'i', 
   'n', 'g', ' ', 'a', 'n', 'd', ' ', 'd', 'i', 's', 
   't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', ' ', 
   'o', 'f', ' ', 't', 'h', 'i', 's', ' ', 'f', 'i', 
   'l', 'e', ',', ' ', 'w', 'i', 't', 'h', ' ', 'o', 
   'r', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', ' ', 
   'm', 'o', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 
   'o', 'n', ',', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'a', 'r', 'e', ' ', 'p', 
   'e', 'r', 'm', 'i', 't', 't', 'e', 'd', ' ', 'i', 
   'n', ' ', 'a', 'n', 'y', ' ', 'm', 'e', 'd', 'i', 
   'u', 'm', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', 
   ' ', 'r', 'o', 'y', 'a', 'l', 't', 'y', ' ', 'p', 
   'r', 'o', 'v', 'i', 'd', 'e', 'd', ' ', 't', 'h', 
   'e', ' ', 'c', 'o', 'p', 'y', 'r', 'i', 'g', 'h', 
   't', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'n', 'o', 't', 'i', 'c', 
   'e', ' ', 'a', 'n', 'd', ' ', 't', 'h', 'i', 's', 
   ' ', 'n', 'o', 't', 'i', 'c', 'e', ' ', 'a', 'r', 
   'e', ' ', 'p', 'r', 'e', 's', 'e', 'r', 'v', 'e', 
   'd', '.', ' ', ' ', '-', '-', '>', '\n', 
  '\n', 
  '<', '!', '-', '-', ' ', 't', 'r', 'a', 'c', 'e', 
   'f', 'r', 'a', 'm', 'e', '-', 'i', 'n', 'f', 'o', 
   ':', ' ', 'R', 'o', 'o', 't', ' ', 'e', 'l', 'e', 
   'm', 'e', 'n', 't', ' ', 'w', 'i', 't', 'h', ' ', 
   'v', 'e', 'r', 's', 'i', 'o', 'n', 'i', 'n', 'g', 
   ' ', '-', '-', '>', '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   't', 'r', 'a', 'c', 'e', 'f', 'r', 'a', 'm', 'e', 
   '-', 'i', 'n', 'f', 'o', ' ', ' ', '(', 'm', 'e', 
   'm', 'o', 'r', 'y', ' ', '|', ' ', 't', 'v', 'a', 
   'r', ')', '*', ' ', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   't', 'r', 'a', 'c', 'e', 'f', 'r', 'a', 'm', 'e', 
   '-', 'i', 'n', 'f', 'o', ' ', ' ', 'v', 'e', 'r', 
   's', 'i', 'o', 'n', ' ', 'C', 'D', 'A', 'T', 'A', 
   ' ', ' ', ' ', '#', 'F', 'I', 'X', 'E', 'D', ' ', 
   ' ', '"', '1', '.', '0', '"', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'm', 'e', 'm', 'o', 'r', 'y', ' ', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', 'E', 'M', 'P', 'T', 'Y', '>', 
   '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'm', 'e', 'm', 'o', 'r', 'y', ' ', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', 's', 't', 'a', 'r', 't', ' ', 
   ' ', ' ', 'C', 'D', 'A', 'T', 'A', ' ', ' ', ' ', 
   '#', 'R', 'E', 'Q', 'U', 'I', 'R', 'E', 'D', '\n', 
  ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', 'l', 'e', 'n', 'g', 't', 'h', 
   ' ', ' ', 'C', 'D', 'A', 'T', 'A', ' ', ' ', ' ', 
   '#', 'R', 'E', 'Q', 'U', 'I', 'R', 'E', 'D', '>', 
   '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   't', 'v', 'a', 'r', ' ', ' ', ' ', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', 'E', 'M', 'P', 'T', 'Y', '>', 
   '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   't', 'v', 'a', 'r', ' ', ' ', ' ', ' ', ' ', ' ', 
   ' ', ' ', ' ', ' ', 'i', 'd', ' ', ' ', ' ', 'C', 
   'D', 'A', 'T', 'A', ' ', ' ', ' ', '#', 'R', 'E', 
   'Q', 'U', 'I', 'R', 'E', 'D', '>', '\n', 
  0 };
static const char xml_feature_xinclude_dtd[] = {
  '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
   'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
   '0', '0', '7', '-', '2', '0', '2', '4', ' ', 'F', 
   'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
   'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
   'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
  '\n', 
  ' ', ' ', ' ', ' ', ' ', 'C', 'o', 'p', 'y', 'i', 
   'n', 'g', ' ', 'a', 'n', 'd', ' ', 'd', 'i', 's', 
   't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', ' ', 
   'o', 'f', ' ', 't', 'h', 'i', 's', ' ', 'f', 'i', 
   'l', 'e', ',', ' ', 'w', 'i', 't', 'h', ' ', 'o', 
   'r', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', ' ', 
   'm', 'o', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 
   'o', 'n', ',', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'a', 'r', 'e', ' ', 'p', 
   'e', 'r', 'm', 'i', 't', 't', 'e', 'd', ' ', 'i', 
   'n', ' ', 'a', 'n', 'y', ' ', 'm', 'e', 'd', 'i', 
   'u', 'm', ' ', 'w', 'i', 't', 'h', 'o', 'u', 't', 
   ' ', 'r', 'o', 'y', 'a', 'l', 't', 'y', ' ', 'p', 
   'r', 'o', 'v', 'i', 'd', 'e', 'd', ' ', 't', 'h', 
   'e', ' ', 'c', 'o', 'p', 'y', 'r', 'i', 'g', 'h', 
   't', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'n', 'o', 't', 'i', 'c', 
   'e', ' ', 'a', 'n', 'd', ' ', 't', 'h', 'i', 's', 
   ' ', 'n', 'o', 't', 'i', 'c', 'e', ' ', 'a', 'r', 
   'e', ' ', 'p', 'r', 'e', 's', 'e', 'r', 'v', 'e', 
   'd', '.', ' ', ' ', '-', '-', '>', '\n', 
  '\n', 
  '<', '!', '-', '-', ' ', 'G', 'D', 'B', ' ', 's', 
   'u', 'p', 'p', 'o', 'r', 't', 's', ' ', 'a', ' ', 
   's', 'u', 'b', 's', 'e', 't', ' ', 'o', 'f', ' ', 
   'X', 'I', 'n', 'c', 'l', 'u', 'd', 'e', '.', ' ', 
   ' ', 'O', 'n', 'l', 'y', ' ', 'w', 'h', 'o', 'l', 
   'e', ' ', 'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 
   's', ' ', 'c', 'a', 'n', '\n', 
  ' ', ' ', ' ', ' ', ' ', 'b', 'e', ' ', 'i', 'n', 
   'c', 'l', 'u', 'd', 'e', 'd', ',', ' ', 'a', 'n', 
   'd', ' ', 'o', 'n', 'l', 'y', ' ', 'a', 's', ' ', 
   'X', 'M', 'L', '.', ' ', ' ', '-', '-', '>', '\n', 
  '\n', 
  '<', '!', 'E', 'L', 'E', 'M', 'E', 'N', 'T', ' ', 
   'x', 'i', ':', 'i', 'n', 'c', 'l', 'u', 'd', 'e', 
   '\011', 'E', 'M', 'P', 'T', 'Y', '>', '\n', 
  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
   'x', 'i', ':', 'i', 'n', 'c', 'l', 'u', 'd', 'e', 
   '\n', 
  '\011', 'x', 'm', 'l', 'n', 's', ':', 'x', 'i', '\011', 
   'C', 'D', 'A', 'T', 'A', '\011', '#', 'F', 'I', 'X', 
   'E', 'D', ' ', '"', 'h', 't', 't', 'p', ':', '/', 
   '/', 'w', 'w', 'w', '.', 'w', '3', '.', 'o', 'r', 
   'g', '/', '2', '0', '0', '1', '/', 'X', 'I', 'n', 
   'c', 'l', 'u', 'd', 'e', '"', '\n', 
  '\011', 'h', 'r', 'e', 'f', '\011', '\011', 'C', 'D', 'A', 
   'T', 'A', '\011', '#', 'R', 'E', 'Q', 'U', 'I', 'R', 
   'E', 'D', '>', '\n', 
  0 };

extern const char *const xml_builtin[][2] = {
  { "btrace.dtd", xml_feature_btrace_dtd },
  { "btrace-conf.dtd", xml_feature_btrace_conf_dtd },
  { "gdb-target.dtd", xml_feature_gdb_target_dtd },
  { "library-list.dtd", xml_feature_library_list_dtd },
  { "library-list-aix.dtd", xml_feature_library_list_aix_dtd },
  { "library-list-svr4.dtd", xml_feature_library_list_svr4_dtd },
  { "osdata.dtd", xml_feature_osdata_dtd },
  { "threads.dtd", xml_feature_threads_dtd },
  { "traceframe-info.dtd", xml_feature_traceframe_info_dtd },
  { "xinclude.dtd", xml_feature_xinclude_dtd },
  { 0, 0 }
};
